@@ -34,6 +34,7 @@ __all__ = [
     "debounced",
     "EmissionInfo",
     "EmitLoopError",
+    "emit_queued",
     "evented",
     "EventedModel",
     "get_evented_namespace",
@@ -53,17 +54,20 @@ if os.getenv("PSYGNAL_UNCOMPILED"):
         "PSYGNAL_UNCOMPILED no longer has any effect. If you wish to run psygnal "
         "without compiled files, you can run:\n\n"
         'python -c "import psygnal.utils; psygnal.utils.decompile()"\n\n'
-        "(You will need to reinstall psygnal to get the compiled version back.)"
+        "(You will need to reinstall psygnal to get the compiled version back.)",
+        stacklevel=2,
     )
 
 from ._evented_decorator import evented
+from ._exceptions import EmitLoopError
 from ._group import EmissionInfo, SignalGroup
 from ._group_descriptor import (
     SignalGroupDescriptor,
     get_evented_namespace,
     is_evented,
 )
-from ._signal import EmitLoopError, Signal, SignalInstance, _compiled
+from ._queue import emit_queued
+from ._signal import Signal, SignalInstance, _compiled
 from ._throttler import debounced, throttled
 
 
