@@ -25,9 +25,9 @@ from __future__ import annotations  # pragma: no cover
 
 from typing import Any, Iterable, MutableSequence, TypeVar, Union, cast, overload
 
-from .._group import EmissionInfo, SignalGroup
-from .._signal import Signal, SignalInstance
-from ..utils import iter_signal_instances
+from psygnal._group import EmissionInfo, SignalGroup
+from psygnal._signal import Signal, SignalInstance
+from psygnal.utils import iter_signal_instances
 
 _T = TypeVar("_T")
 Index = Union[int, slice]
@@ -136,7 +136,7 @@ class EventedList(MutableSequence[_T]):
     def __getitem__(self, key: slice) -> EventedList[_T]:
         ...
 
-    def __getitem__(self, key: Index) -> Union[_T, EventedList[_T]]:
+    def __getitem__(self, key: Index) -> _T | EventedList[_T]:
         """Return self[key]."""
         result = self._data[key]
         return self.__newlike__(result) if isinstance(result, list) else result
@@ -149,20 +149,22 @@ class EventedList(MutableSequence[_T]):
     def __setitem__(self, key: slice, value: Iterable[_T]) -> None:
         ...
 
-    def __setitem__(self, key: Index, value: Union[_T, Iterable[_T]]) -> None:
+    def __setitem__(self, key: Index, value: _T | Iterable[_T]) -> None:
         """Set self[key] to value."""
         old = self._data[key]
         if value is old:
             return
 
+        # sourcery skip: hoist-similar-statement-from-if, hoist-statement-from-if
         if isinstance(key, slice):
             if not isinstance(value, Iterable):
                 raise TypeError("Can only assign an iterable to slice")
             value = [self._pre_insert(v) for v in value]  # before we mutate the list
+            self._data[key] = value
         else:
             value = self._pre_insert(cast("_T", value))
+            self._data[key] = value
 
-        self._data[key] = value  # type: ignore
         self.events.changed.emit(key, old, value)
 
     def __delitem__(self, key: Index) -> None:
@@ -354,7 +356,7 @@ class EventedList(MutableSequence[_T]):
             else:
                 raise TypeError(
                     "Can only move integer or slice indices"
-                )  # pragma: no cover # noqa
+                )  # pragma: no cover
 
         to_move = list(dict.fromkeys(to_move))
 
