@@ -1,10 +1,9 @@
 from __future__ import annotations
 
-from enum import Enum
 from itertools import chain
-from typing import Any, Dict, Iterable, Iterator, MutableSet, Set, Tuple, TypeVar, Union
+from typing import Any, Iterable, Iterator, MutableSet, TypeVar
 
-from typing_extensions import Final, Literal
+from typing_extensions import Final
 
 from psygnal import Signal, SignalGroup
 
@@ -12,16 +11,15 @@ _T = TypeVar("_T")
 _Cls = TypeVar("_Cls", bound="_BaseMutableSet")
 
 
-class _BAIL(Enum):
-    BAIL = 0
+class BailType:
+    pass
 
 
-BAIL: Final = _BAIL.BAIL
-BailType = Literal[_BAIL.BAIL]
+BAIL: Final = BailType()
 
 
 class _BaseMutableSet(MutableSet[_T]):
-    _data: Set[_T]  # pragma: no cover
+    _data: set[_T]  # pragma: no cover
 
     def __init__(self, iterable: Iterable[_T] = ()):
         self._data = set()
@@ -33,7 +31,7 @@ class _BaseMutableSet(MutableSet[_T]):
         This has no effect if the element is already present.
         """
         _item = self._pre_add_hook(item)
-        if _item is not BAIL:
+        if not isinstance(_item, BailType):
             self._do_add(_item)
             self._post_add_hook(_item)
 
@@ -48,7 +46,7 @@ class _BaseMutableSet(MutableSet[_T]):
         If the element is not a member, do nothing.
         """
         _item = self._pre_discard_hook(item)
-        if _item is not BAIL:
+        if not isinstance(_item, BailType):
             self._do_discard(_item)
             self._post_discard_hook(_item)
 
@@ -70,13 +68,13 @@ class _BaseMutableSet(MutableSet[_T]):
 
     # --------
 
-    def _pre_add_hook(self, item: _T) -> Union[_T, BailType]:
+    def _pre_add_hook(self, item: _T) -> _T | BailType:
         return item  # pragma: no cover
 
     def _post_add_hook(self, item: _T) -> None:
         ...  # pragma: no cover
 
-    def _pre_discard_hook(self, item: _T) -> Union[_T, BailType]:
+    def _pre_discard_hook(self, item: _T) -> _T | BailType:
         return item  # pragma: no cover
 
     def _post_discard_hook(self, item: _T) -> None:
@@ -164,7 +162,7 @@ class _BaseMutableSet(MutableSet[_T]):
 class OrderedSet(_BaseMutableSet[_T]):
     """A set that preserves insertion order, uses dict behind the scenes."""
 
-    _data: Dict[_T, None]  # type: ignore  # pragma: no cover
+    _data: dict[_T, None]  # type: ignore  # pragma: no cover
 
     def __init__(self, iterable: Iterable[_T] = ()):
         self._data = {}
@@ -264,19 +262,19 @@ class EventedSet(_BaseMutableSet[_T]):
         with self.events.items_changed.paused(_reduce_events, ((), ())):
             super().symmetric_difference_update(__s)
 
-    def _pre_add_hook(self, item: _T) -> Union[_T, BailType]:
+    def _pre_add_hook(self, item: _T) -> _T | BailType:
         return BAIL if item in self else item
 
     def _post_add_hook(self, item: _T) -> None:
         self._emit_change((item,), ())
 
-    def _pre_discard_hook(self, item: _T) -> Union[_T, BailType]:
+    def _pre_discard_hook(self, item: _T) -> _T | BailType:
         return BAIL if item not in self else item
 
     def _post_discard_hook(self, item: _T) -> None:
         self._emit_change((), (item,))
 
-    def _emit_change(self, added: Tuple[_T, ...], removed: Tuple[_T, ...]) -> None:
+    def _emit_change(self, added: tuple[_T, ...], removed: tuple[_T, ...]) -> None:
         """Emit a change event."""
         self.events.items_changed.emit(added, removed)
 
