@@ -1,7 +1,10 @@
 """qtbot should work for testing!"""
+from threading import Thread, current_thread, main_thread
 from typing import TYPE_CHECKING, Any, Callable, Tuple
+from unittest.mock import Mock
 
 import pytest
+from typing_extensions import Literal
 
 from psygnal import Signal
 from psygnal._signal import _guess_qtsignal_signature
@@ -98,3 +101,46 @@ def test_connect_qt_signal_instance(qtbot: "QtBot") -> None:
     with pytest.raises(ValueError):
         e.sig1.connect(q_obj.qsig2.emit)
     e.sig1.emit()
+
+
+@pytest.mark.parametrize("thread", [None, "main"])
+def test_q_main_thread_emit(
+    thread: Literal["main", None], qtbot: "QtBot", qapp
+) -> None:
+    """Test using signal.emit(..., queue=True)
+
+    ... and receiving it on the main thread with a QTimer connected to `emit_queued`
+    """
+    from psygnal.qt import start_emitting_from_queue, stop_emitting_from_queue
+
+    class C:
+        sig = Signal(int)
+
+    obj = C()
+    mock = Mock()
+
+    @obj.sig.connect(thread=thread)
+    def _some_slot(val: int) -> None:
+        mock(val)
+        assert (current_thread() == main_thread()) == (thread == "main")
+
+    def _emit_from_thread() -> None:
+        assert current_thread() != main_thread()
+        obj.sig.emit(1)
+
+    with qtbot.waitSignal(obj.sig, timeout=1000):
+        t = Thread(target=_emit_from_thread)
+        t.start()
+        t.join()
+
+    qapp.processEvents()
+    if thread is None:
+        mock.assert_called_once_with(1)
+    else:
+        mock.assert_not_called()
+        start_emitting_from_queue()
+        qapp.processEvents()
+        mock.assert_called_once_with(1)
+
+        start_emitting_from_queue(10)  # just for test coverage
+        stop_emitting_from_queue()
