@@ -1,7 +1,7 @@
 import time
 from unittest.mock import Mock
 
-from psygnal._throttler import debounced, throttled
+from psygnal import debounced, throttled
 
 
 def test_debounced() -> None:
@@ -9,7 +9,9 @@ def test_debounced() -> None:
     f1 = debounced(mock1, timeout=10, leading=False)
     f2 = Mock()
 
-    [(f1(), f2()) for _ in range(10)]
+    for _ in range(10):
+        f1()
+        f2()
 
     time.sleep(0.1)
     mock1.assert_called_once()
@@ -22,7 +24,9 @@ def test_debounced_leading() -> None:
     f1 = debounced(mock1, timeout=10, leading=True)
     f2 = Mock()
 
-    [(f1(), f2()) for _ in range(10)]
+    for _ in range(10):
+        f1()
+        f2()
 
     time.sleep(0.1)
     assert mock1.call_count == 2
@@ -34,7 +38,9 @@ def test_throttled() -> None:
     f1 = throttled(mock1, timeout=10, leading=True)
     f2 = Mock()
 
-    [(f1(), f2()) for _ in range(10)]
+    for _ in range(10):
+        f1()
+        f2()
 
     time.sleep(0.1)
     assert mock1.call_count == 2
@@ -46,28 +52,30 @@ def test_throttled_trailing() -> None:
     f1 = throttled(mock1, timeout=10, leading=False)
     f2 = Mock()
 
-    [(f1(), f2()) for _ in range(10)]
+    for _ in range(10):
+        f1()
+        f2()
 
     time.sleep(0.1)
     assert mock1.call_count == 1
     assert f2.call_count == 10
 
 
-def test_cancel():
+def test_cancel() -> None:
     mock1 = Mock()
     f1 = debounced(mock1, timeout=50, leading=False)
     f1()
     f1()
-    f1.cancel()  # type: ignore
+    f1.cancel()
     time.sleep(0.2)
     mock1.assert_not_called()
 
 
-def test_flush():
+def test_flush() -> None:
     mock1 = Mock()
     f1 = debounced(mock1, timeout=50, leading=False)
     f1()
     f1()
-    f1.flush()  # type: ignore
+    f1.flush()
     time.sleep(0.2)
     mock1.assert_called_once()
